import string

__all__ = [
    "DEFAULT_RANDOM_ID_MAX_LENGTH", "DEFAULT_RANDOM_ID_CHARS", "DEFAULT_TOKEN_MAX_LENGTH",
    "DEFAULT_TOKEN_CHARS", "TOKEN_CREATE_ON_CREATION"
]

DEFAULT_RANDOM_ID_MAX_LENGTH = 1023
DEFAULT_RANDOM_ID_CHARS = string.ascii_letters + string.digits
DEFAULT_TOKEN_MAX_LENGTH = 2047
DEFAULT_TOKEN_CHARS = string.ascii_letters + string.digits
TOKEN_CREATE_ON_CREATION = True
