from django.apps import AppConfig


class DjangoModelMixinsConfig(AppConfig):
    """Configuration for `django-model-mixins`."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "django_model_mixins"
